17263808 Unable to initialize LDAP configuration using profile name
authorDrew Fisher <drew.fisher@oracle.com>
Fri, 02 Aug 2013 14:40:12 -0600
changeset 1418 d562fd15d944
parent 1417 5158e071d299
child 1419 a13e688bbe2d
17263808 Unable to initialize LDAP configuration using profile name 17263843 LDAP parameters do not match expected parameters
components/puppet/files/solaris/lib/puppet/provider/ldap/solaris.rb
components/puppet/files/solaris/lib/puppet/type/ldap.rb
--- a/components/puppet/files/solaris/lib/puppet/type/ldap.rb	Thu Aug 01 14:53:52 2013 -0600
+++ b/components/puppet/files/solaris/lib/puppet/type/ldap.rb	Fri Aug 02 14:40:12 2013 -0600
@@ -335,7 +335,7 @@
         self.pg = "cred"
     end
 
-    newproperty(:admin_dn) do
+    newproperty(:admin_bind_dn) do
         desc "The Bind Distinguised Name for the administrator identity that
               is used for shadow information update"
         class << self
@@ -344,7 +344,7 @@
         self.pg = "cred"
     end
 
-    newproperty(:admin_password) do
+    newproperty(:admin_bind_passwd) do
         desc "The administrator password"
         class << self
             attr_accessor :pg
--- a/components/puppet/files/solaris/lib/puppet/provider/ldap/solaris.rb	Thu Aug 01 14:53:52 2013 -0600
+++ b/components/puppet/files/solaris/lib/puppet/provider/ldap/solaris.rb	Fri Aug 02 14:40:12 2013 -0600
@@ -51,7 +51,7 @@
 
             pg, prop = fullprop.split("/")
 
             # handle the domainname differently as it's not in validprops
             if prop == "profile"
                 props[:name] = value
             else
@@ -100,6 +100,10 @@
     end
 
     def flush
+        # the namevar is a param and will never get set by the setters defined
+        # above.  It must always be specified, so set it here.
+        svccfg("-s", @@ldap_fmri, "setprop", "config/profile", "=",
+               @resource[:name])
         svccfg("-s", @@ldap_fmri, "refresh")
     end
 end
@@ -51,7 +51,7 @@
             pg, prop = fullprop.split("/")
 
-            # handle the domainname differently as it's not in validprops
+            # handle the profile name differently as it's not in validprops
             if prop == "profile"
                 props[:name] = value